# Setupr, ships the Worldr infrastructure…

<img src="https://github.com/worldr/setupr/blob/main/docs/assets/logo.png" width=25% height=25% >

[![PyPi status](https://img.shields.io/pypi/status/Setupr)](https://img.shields.io/pypi/status/Setupr)
[![PyPi version](https://img.shields.io/pypi/v/setupr)](https://img.shields.io/pypi/v/setupr)
[![PyPi python versions](https://img.shields.io/pypi/pyversions/Setupr)](https://img.shields.io/pypi/pyversions/Setupr)
[![PyPi downloads](https://img.shields.io/pypi/dm/setupr)](https://img.shields.io/pypi/dm/Setupr)

[![Release](https://img.shields.io/github/v/release/worldr/setupr)](https://img.shields.io/github/v/release/worldr/setupr)
[![Build status](https://img.shields.io/github/workflow/status/worldr/setupr/merge-to-main)](https://img.shields.io/github/workflow/status/worldr/setupr/merge-to-main)
[![Commit activity](https://img.shields.io/github/commit-activity/m/worldr/setupr)](https://img.shields.io/github/commit-activity/m/worldr/setupr)
[![Code style with black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports with isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)

----

## Documentation

- [Installation](docs/installation.md)
- [Usage](docs/usage.md)
- [Development](docs/development.md)

----

## Quick install

```bash
python -venv worldr
source ./worldr/bin/activate
pip install -U setupr
setupr --help
```

---

Repository initiated with [fpgmaas/cookiecutter-poetry](https://github.com/fpgmaas/cookiecutter-poetry).
